# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# NO CHECKED-IN PROTOBUF GENCODE
# source: tars.proto
# Protobuf Python Version: 6.31.1
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import runtime_version as _runtime_version
from google.protobuf import symbol_database as _symbol_database
from google.protobuf.internal import builder as _builder
_runtime_version.ValidateProtobufRuntimeVersion(
    _runtime_version.Domain.PUBLIC,
    6,
    31,
    1,
    '',
    'tars.proto'
)
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\ntars.proto\x12\x04tars\"\x07\n\x05\x45mpty\"\xcb\x01\n\x0eHealthResponse\x12\x0e\n\x06status\x18\x01 \x01(\t\x12\x0f\n\x07version\x18\x02 \x01(\t\x12\x16\n\x0egrpc_available\x18\x03 \x01(\x08\x12\x18\n\x10webrtc_available\x18\x04 \x01(\x08\x12\x18\n\x10webrtc_connected\x18\x05 \x01(\x08\x12&\n\x08hardware\x18\x06 \x01(\x0b\x32\x14.tars.HardwareStatus\x12$\n\x07\x62\x61ttery\x18\x07 \x01(\x0b\x32\x13.tars.BatteryStatus\"q\n\x0eHardwareStatus\x12\x0e\n\x06servos\x18\x01 \x01(\x08\x12\x0e\n\x06\x63\x61mera\x18\x02 \x01(\x08\x12\r\n\x05\x61udio\x18\x03 \x01(\x08\x12\x0f\n\x07\x64isplay\x18\x04 \x01(\x08\x12\x0f\n\x07\x62\x61ttery\x18\x05 \x01(\x08\x12\x0e\n\x06moving\x18\x06 \x01(\x08\"\x8c\x01\n\x0fVersionResponse\x12\x0f\n\x07version\x18\x01 \x01(\t\x12\x12\n\ngit_commit\x18\x02 \x01(\t\x12\x12\n\nbuild_date\x18\x03 \x01(\t\x12\x16\n\x0epython_version\x18\x04 \x01(\t\x12\x10\n\x08platform\x18\x05 \x01(\t\x12\x16\n\x0eminimum_client\x18\x06 \x01(\t\"\xaf\x01\n\x13UpdateCheckResponse\x12\x18\n\x10update_available\x18\x01 \x01(\x08\x12\x17\n\x0f\x63urrent_version\x18\x02 \x01(\t\x12\x16\n\x0elatest_version\x18\x03 \x01(\t\x12\x10\n\x08severity\x18\x04 \x01(\t\x12\x15\n\rrelease_notes\x18\x05 \x01(\t\x12\x10\n\x08pypi_url\x18\x06 \x01(\t\x12\x12\n\ngithub_url\x18\x07 \x01(\t\".\n\x0bMoveRequest\x12\x10\n\x08movement\x18\x01 \x01(\t\x12\r\n\x05speed\x18\x02 \x01(\x02\"@\n\x0cMoveResponse\x12\x0f\n\x07success\x18\x01 \x01(\x08\x12\x10\n\x08\x64uration\x18\x02 \x01(\x02\x12\r\n\x05\x65rror\x18\x03 \x01(\t\"!\n\x0e\x45motionRequest\x12\x0f\n\x07\x65motion\x18\x01 \x01(\t\" \n\x0f\x45yeStateRequest\x12\r\n\x05state\x18\x01 \x01(\t\"@\n\x0e\x43\x61ptureRequest\x12\r\n\x05width\x18\x01 \x01(\x05\x12\x0e\n\x06height\x18\x02 \x01(\x05\x12\x0f\n\x07quality\x18\x03 \x01(\x05\"O\n\x0f\x43\x61ptureResponse\x12\r\n\x05image\x18\x01 \x01(\x0c\x12\r\n\x05width\x18\x02 \x01(\x05\x12\x0e\n\x06height\x18\x03 \x01(\x05\x12\x0e\n\x06\x66ormat\x18\x04 \x01(\t\"\xaa\x01\n\x0eStatusResponse\x12\x11\n\tconnected\x18\x01 \x01(\x08\x12$\n\x07\x62\x61ttery\x18\x02 \x01(\x0b\x32\x13.tars.BatteryStatus\x12\x17\n\x0f\x63urrent_emotion\x18\x03 \x01(\t\x12\x19\n\x11\x63urrent_eye_state\x18\x04 \x01(\t\x12\x11\n\tis_moving\x18\x05 \x01(\x08\x12\x18\n\x10\x63urrent_movement\x18\x06 \x01(\t\"R\n\rBatteryStatus\x12\r\n\x05level\x18\x01 \x01(\x05\x12\x10\n\x08\x63harging\x18\x02 \x01(\x08\x12\x0f\n\x07voltage\x18\x03 \x01(\x02\x12\x0f\n\x07\x63urrent\x18\x04 \x01(\x02\"D\n\x0eMovementStatus\x12\x0e\n\x06moving\x18\x01 \x01(\x08\x12\x10\n\x08movement\x18\x02 \x01(\t\x12\x10\n\x08progress\x18\x03 \x01(\x02\"\"\n\x11\x41udioLevelRequest\x12\r\n\x05level\x18\x01 \x01(\x02\"&\n\x12\x41udioLevelResponse\x12\x10\n\x08received\x18\x01 \x01(\x08\"\x1f\n\x0eMicMuteRequest\x12\r\n\x05muted\x18\x01 \x01(\x08\" \n\x0fMicMuteResponse\x12\r\n\x05muted\x18\x01 \x01(\x08\x32\xe8\x05\n\x0bTarsService\x12+\n\x06Health\x12\x0b.tars.Empty\x1a\x14.tars.HealthResponse\x12.\n\tGetStatus\x12\x0b.tars.Empty\x1a\x14.tars.StatusResponse\x12\x30\n\nGetVersion\x12\x0b.tars.Empty\x1a\x15.tars.VersionResponse\x12\x35\n\x0b\x43heckUpdate\x12\x0b.tars.Empty\x1a\x19.tars.UpdateCheckResponse\x12-\n\x04Move\x12\x11.tars.MoveRequest\x1a\x12.tars.MoveResponse\x12!\n\x05Reset\x12\x0b.tars.Empty\x1a\x0b.tars.Empty\x12/\n\nSetEmotion\x12\x14.tars.EmotionRequest\x1a\x0b.tars.Empty\x12\x31\n\x0bSetEyeState\x12\x15.tars.EyeStateRequest\x1a\x0b.tars.Empty\x12<\n\rCaptureCamera\x12\x14.tars.CaptureRequest\x1a\x15.tars.CaptureResponse\x12\x33\n\rStreamBattery\x12\x0b.tars.Empty\x1a\x13.tars.BatteryStatus0\x01\x12;\n\x14StreamMovementStatus\x12\x0b.tars.Empty\x1a\x14.tars.MovementStatus0\x01\x12J\n\x11StreamAudioLevels\x12\x17.tars.AudioLevelRequest\x1a\x18.tars.AudioLevelResponse(\x01\x30\x01\x12/\n\nSetMicMute\x12\x14.tars.MicMuteRequest\x1a\x0b.tars.Empty\x12\x30\n\nGetMicMute\x12\x0b.tars.Empty\x1a\x15.tars.MicMuteResponseb\x06proto3')

_globals = globals()
_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, _globals)
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'tars_pb2', _globals)
if not _descriptor._USE_C_DESCRIPTORS:
  DESCRIPTOR._loaded_options = None
  _globals['_EMPTY']._serialized_start=20
  _globals['_EMPTY']._serialized_end=27
  _globals['_HEALTHRESPONSE']._serialized_start=30
  _globals['_HEALTHRESPONSE']._serialized_end=233
  _globals['_HARDWARESTATUS']._serialized_start=235
  _globals['_HARDWARESTATUS']._serialized_end=348
  _globals['_VERSIONRESPONSE']._serialized_start=351
  _globals['_VERSIONRESPONSE']._serialized_end=491
  _globals['_UPDATECHECKRESPONSE']._serialized_start=494
  _globals['_UPDATECHECKRESPONSE']._serialized_end=669
  _globals['_MOVEREQUEST']._serialized_start=671
  _globals['_MOVEREQUEST']._serialized_end=717
  _globals['_MOVERESPONSE']._serialized_start=719
  _globals['_MOVERESPONSE']._serialized_end=783
  _globals['_EMOTIONREQUEST']._serialized_start=785
  _globals['_EMOTIONREQUEST']._serialized_end=818
  _globals['_EYESTATEREQUEST']._serialized_start=820
  _globals['_EYESTATEREQUEST']._serialized_end=852
  _globals['_CAPTUREREQUEST']._serialized_start=854
  _globals['_CAPTUREREQUEST']._serialized_end=918
  _globals['_CAPTURERESPONSE']._serialized_start=920
  _globals['_CAPTURERESPONSE']._serialized_end=999
  _globals['_STATUSRESPONSE']._serialized_start=1002
  _globals['_STATUSRESPONSE']._serialized_end=1172
  _globals['_BATTERYSTATUS']._serialized_start=1174
  _globals['_BATTERYSTATUS']._serialized_end=1256
  _globals['_MOVEMENTSTATUS']._serialized_start=1258
  _globals['_MOVEMENTSTATUS']._serialized_end=1326
  _globals['_AUDIOLEVELREQUEST']._serialized_start=1328
  _globals['_AUDIOLEVELREQUEST']._serialized_end=1362
  _globals['_AUDIOLEVELRESPONSE']._serialized_start=1364
  _globals['_AUDIOLEVELRESPONSE']._serialized_end=1402
  _globals['_MICMUTEREQUEST']._serialized_start=1404
  _globals['_MICMUTEREQUEST']._serialized_end=1435
  _globals['_MICMUTERESPONSE']._serialized_start=1437
  _globals['_MICMUTERESPONSE']._serialized_end=1469
  _globals['_TARSSERVICE']._serialized_start=1472
  _globals['_TARSSERVICE']._serialized_end=2216
# @@protoc_insertion_point(module_scope)
